/********************************************************************
 Mod5282 ioboard.c Development Board driver.

 This driver is released as a patch to the 1.80 NetBurner Tools 
 Release.

 Instructions on using this file:
	1. Open a command prompt and go to the \nburn\mod5282\system directory
	2. Rename ioboard.c to ioboard.bak
	3. Copy the new ioboard.c into the directory
	4. Run "make clean"
	5. Run "make"


 Revision History:
 	Initial Release, 5/20/2003
 	Revision 1.01, 6/10/2003
 		Adds putdisp() function to write 7-segment dispay 
 *******************************************************************/
#include "predef.h"
#include <stdio.h>
#include "sim5282.h"           /*on-chip register definitions*/
#include "includes.h"
#include "cfinter.h"
#include "constants.h"
#include "iosys.h"
#include "bsp.h"
#include "system.h"
#include "utils.h"


static bInit;
static PBYTE pLed;

#define BASEADDRESS (0xA0000000)


/*-------------------------------------------------------------------
 Function to initialize the Mod5282 Development Board. Configures
 chip selects, sets LED bank and 7-segment LED display to off.
 -------------------------------------------------------------------*/
void InitChipBoardSelect()
{
	sim.cs[3].csar=(BASEADDRESS>>16);
	sim.cs[3].cscr=0x2140; /* 0010 0001 0110  0000 */
	sim.cs[3].csmr=0x001F0001;
	pLed=(PBYTE)BASEADDRESS;
	pLed[1]=0xFF;
	pLed[2]=0xFF;
	bInit=TRUE;
}



/*-------------------------------------------------------------------
 Function to read dip switch settings. Returns 8-bit value where
 each bit represents 1 switch.
 -------------------------------------------------------------------*/
unsigned char getdipsw()
{
	if (!bInit) 
		InitChipBoardSelect();
	return *pLed;
}


/*-------------------------------------------------------------------
 Write value to LED bank. Each bit of passed 8-bit value represents
 one LED.
 -------------------------------------------------------------------*/
void putleds(unsigned char c)
{
	if (!bInit) InitChipBoardSelect();
	*pLed=c;
}


/*-------------------------------------------------------------------
 Write value to 7-segment LED display. For example, a hex value of 
 0x1234 will be seen as 1234 on the LED display. A nibble value of 
 F will blank (clear) a digit. Nibble values of 0xA to E are 
 undefined.
 -------------------------------------------------------------------*/
void putdisp(unsigned short w)
{
	BYTE b1=(w>>8);
	BYTE b2=(w & 0xFF);
	if (!bInit) InitChipBoardSelect();
	pLed[1]=b1;
	pLed[2]=b2;
}


